Function ARSkeletonJointNameForRecognizedPointKey

pub unsafe extern "C-unwind" fn ARSkeletonJointNameForRecognizedPointKey(
    recognized_point_key: &VNRecognizedPointKey,
) -> Option<Retained<ARSkeletonJointName>>
Available on crate features ARSkeleton and ARSkeletonDefinition and objc2 and objc2-foundation and objc2-vision only.
Returns the landmark joint name that corresponds to a key point defined in Vision framework.

See: VNRecognizedPointKey, VNDetectHumanBodyPoseRequest

If an invalid key point is passed the returned point will be nil.

Parameter recognizedPointKey: Recognized key point.

Returns: Joint name that could be mapped to a ARSkeleton2D. Nil if no mapping exists.