pub struct ARCoachingOverlayView { /* private fields */ }ARCoachingOverlayView and objc2-ui-kit and objc2 only.Expand description
A view that guides users through session initialization
The view will use context aware messaging and animations to instruct the user on gathering required info for the AR session.
See also Apple’s documentation
Implementations
Sourceimpl ARCoachingOverlayView
impl ARCoachingOverlayView
Sourcepub unsafe fn delegate(
&self,
) -> Option<Retained<ProtocolObject<dyn ARCoachingOverlayViewDelegate>>>
pub unsafe fn delegate( &self, ) -> Option<Retained<ProtocolObject<dyn ARCoachingOverlayViewDelegate>>>
Specifies the delegate used for callbacks
Sourcepub unsafe fn setDelegate(
&self,
delegate: Option<&ProtocolObject<dyn ARCoachingOverlayViewDelegate>>,
)
pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn ARCoachingOverlayViewDelegate>>, )
Setter for delegate.
This is a weak property.
Sourcepub unsafe fn sessionProvider(&self) -> Option<Retained<NSObject>>
Available on crate feature ARSession only.
pub unsafe fn sessionProvider(&self) -> Option<Retained<NSObject>>
ARSession only.A provider of a session to use
This property can be used to set the session when loading from a storyboard. Setting this property at runtime will also
set the session property.
Sourcepub unsafe fn setSessionProvider(&self, session_provider: Option<&NSObject>)
Available on crate feature ARSession only.
pub unsafe fn setSessionProvider(&self, session_provider: Option<&NSObject>)
ARSession only.Setter for sessionProvider.
This is a weak property.
Safety
session_provider must implement ARSessionProviding.
Sourcepub unsafe fn session(&self) -> Option<Retained<ARSession>>
Available on crate feature ARSession only.
pub unsafe fn session(&self) -> Option<Retained<ARSession>>
ARSession only.The session that the view uses to update coaching
Sourcepub unsafe fn setSession(&self, session: Option<&ARSession>)
Available on crate feature ARSession only.
pub unsafe fn setSession(&self, session: Option<&ARSession>)
ARSession only.Setter for session.
Sourcepub unsafe fn goal(&self) -> ARCoachingGoal
pub unsafe fn goal(&self) -> ARCoachingGoal
The coaching type used to resolve what messaging to display to the user while activated
Defaults to ARCoachingGoalTracking
Sourcepub unsafe fn setGoal(&self, goal: ARCoachingGoal)
pub unsafe fn setGoal(&self, goal: ARCoachingGoal)
Setter for goal.
Sourcepub unsafe fn activatesAutomatically(&self) -> bool
pub unsafe fn activatesAutomatically(&self) -> bool
Whether or not the view should activate/deactivate automatically, depending on the current state of the session
Defaults to YES
When set to automatically activate, the view will transition to active when the session loses normal tracking for a set amount
of time.
When tracking resumes and other requirements (based on goal) are met, the view will deactivate.
Sourcepub unsafe fn setActivatesAutomatically(&self, activates_automatically: bool)
pub unsafe fn setActivatesAutomatically(&self, activates_automatically: bool)
Setter for activatesAutomatically.
Sourcepub unsafe fn isActive(&self) -> bool
pub unsafe fn isActive(&self) -> bool
Whether or not the view is currently active.
See: -[ARCoachingOverlayView setActive:animated:]
Sourcepub unsafe fn setActive_animated(&self, active: bool, animated: bool)
pub unsafe fn setActive_animated(&self, active: bool, animated: bool)
Transition the view to either an activated or deactivated state
On activation the view will check the current session, and if relocalization is needed it will present a modified UI with relocalization coaching and a reset button.
On deactivation the view will become hidden
Parameter active: Whether the view should activate, or deactivate
Parameter animated: Whether the view animated to activated/deactivated states, or transitions instantly
See: -[ARCoachingOverlayViewDelegate coachingOverlayViewDidTriggerReset:]
Sourceimpl ARCoachingOverlayView
Methods declared on superclass UIView.
impl ARCoachingOverlayView
Methods declared on superclass UIView.
pub unsafe fn initWithFrame( this: Allocated<Self>, frame: CGRect, ) -> Retained<Self>
objc2-core-foundation only.Sourcepub unsafe fn initWithCoder(
this: Allocated<Self>,
coder: &NSCoder,
) -> Option<Retained<Self>>
Available on crate feature objc2-foundation only.
pub unsafe fn initWithCoder( this: Allocated<Self>, coder: &NSCoder, ) -> Option<Retained<Self>>
objc2-foundation only.Safety
coder possibly has further requirements.
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Sourceimpl ARCoachingOverlayView
Methods declared on superclass NSObject.
impl ARCoachingOverlayView
Methods declared on superclass NSObject.
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
Methods from Deref<Target = UIView>
pub fn isUserInteractionEnabled(&self) -> bool
UIResponder only.Sourcepub fn setUserInteractionEnabled(&self, user_interaction_enabled: bool)
Available on crate feature UIResponder only.
pub fn setUserInteractionEnabled(&self, user_interaction_enabled: bool)
UIResponder only.Setter for isUserInteractionEnabled.
pub fn tag(&self) -> isize
UIResponder only.pub fn canBecomeFocused(&self) -> bool
UIResponder only.pub fn isFocused(&self) -> bool
UIResponder only.Sourcepub fn focusGroupIdentifier(&self) -> Option<Retained<NSString>>
Available on crate feature UIResponder only.
pub fn focusGroupIdentifier(&self) -> Option<Retained<NSString>>
UIResponder only.The identifier of the focus group that this view belongs to. If this is nil, subviews inherit their superview’s focus group.
Sourcepub fn setFocusGroupIdentifier(&self, focus_group_identifier: Option<&NSString>)
Available on crate feature UIResponder only.
pub fn setFocusGroupIdentifier(&self, focus_group_identifier: Option<&NSString>)
UIResponder only.Setter for focusGroupIdentifier.
This is copied when set.
Sourcepub fn focusGroupPriority(&self) -> isize
Available on crate features UIFocus and UIResponder only.
pub fn focusGroupPriority(&self) -> isize
UIFocus and UIResponder only.The priority this item has in its focus group. The higher the priority, the more likely it is to get picked when focus moves into this group. Note: this method can only be used to increase an item’s priority, not decrease it. For example if an item is currently selected, the actual priority of this item will be determined by MAX(focusGroupPriority, UIFocusGroupPrioritySelected).
Sourcepub fn setFocusGroupPriority(&self, focus_group_priority: isize)
Available on crate features UIFocus and UIResponder only.
pub fn setFocusGroupPriority(&self, focus_group_priority: isize)
UIFocus and UIResponder only.Setter for focusGroupPriority.
pub fn semanticContentAttribute(&self) -> UISemanticContentAttribute
UIResponder only.Sourcepub fn setSemanticContentAttribute(
&self,
semantic_content_attribute: UISemanticContentAttribute,
)
Available on crate feature UIResponder only.
pub fn setSemanticContentAttribute( &self, semantic_content_attribute: UISemanticContentAttribute, )
UIResponder only.Setter for semanticContentAttribute.
pub fn isMultipleTouchEnabled(&self) -> bool
UIResponder only.Sourcepub fn setMultipleTouchEnabled(&self, multiple_touch_enabled: bool)
Available on crate feature UIResponder only.
pub fn setMultipleTouchEnabled(&self, multiple_touch_enabled: bool)
UIResponder only.Setter for isMultipleTouchEnabled.
pub fn isExclusiveTouch(&self) -> bool
UIResponder only.Sourcepub fn setExclusiveTouch(&self, exclusive_touch: bool)
Available on crate feature UIResponder only.
pub fn setExclusiveTouch(&self, exclusive_touch: bool)
UIResponder only.Setter for isExclusiveTouch.
pub fn autoresizesSubviews(&self) -> bool
UIResponder only.Sourcepub fn setAutoresizesSubviews(&self, autoresizes_subviews: bool)
Available on crate feature UIResponder only.
pub fn setAutoresizesSubviews(&self, autoresizes_subviews: bool)
UIResponder only.Setter for autoresizesSubviews.
pub fn autoresizingMask(&self) -> UIViewAutoresizing
UIResponder only.Sourcepub fn setAutoresizingMask(&self, autoresizing_mask: UIViewAutoresizing)
Available on crate feature UIResponder only.
pub fn setAutoresizingMask(&self, autoresizing_mask: UIViewAutoresizing)
UIResponder only.Setter for autoresizingMask.
pub fn sizeToFit(&self)
UIResponder only.pub fn superview(&self) -> Option<Retained<UIView>>
UIResponder only.pub fn subviews(&self) -> Retained<NSArray<UIView>>
UIResponder only.pub fn removeFromSuperview(&self)
UIResponder only.pub fn insertSubview_atIndex(&self, view: &UIView, index: isize)
UIResponder only.pub fn exchangeSubviewAtIndex_withSubviewAtIndex( &self, index1: isize, index2: isize, )
UIResponder only.pub fn addSubview(&self, view: &UIView)
UIResponder only.pub fn insertSubview_belowSubview( &self, view: &UIView, sibling_subview: &UIView, )
UIResponder only.pub fn insertSubview_aboveSubview( &self, view: &UIView, sibling_subview: &UIView, )
UIResponder only.pub fn bringSubviewToFront(&self, view: &UIView)
UIResponder only.pub fn sendSubviewToBack(&self, view: &UIView)
UIResponder only.pub fn didAddSubview(&self, subview: &UIView)
UIResponder only.pub fn willRemoveSubview(&self, subview: &UIView)
UIResponder only.pub fn willMoveToSuperview(&self, new_superview: Option<&UIView>)
UIResponder only.pub fn didMoveToSuperview(&self)
UIResponder only.pub fn didMoveToWindow(&self)
UIResponder only.pub fn isDescendantOfView(&self, view: &UIView) -> bool
UIResponder only.pub fn viewWithTag(&self, tag: isize) -> Option<Retained<UIView>>
UIResponder only.Sourcepub fn setNeedsUpdateProperties(&self)
Available on crate feature UIResponder only.
pub fn setNeedsUpdateProperties(&self)
UIResponder only.Call to manually request a properties update for the view. Multiple requests may be coalesced into a single update alongside the next layout pass.
Sourcepub fn updateProperties(&self)
Available on crate feature UIResponder only.
pub fn updateProperties(&self)
UIResponder only.Override point for subclasses to update properties of this view.
Never call this method directly; use setNeedsUpdateProperties to schedule an update.
Sourcepub fn updatePropertiesIfNeeded(&self)
Available on crate feature UIResponder only.
pub fn updatePropertiesIfNeeded(&self)
UIResponder only.Forces an immediate properties update for this view (and its view controller, if applicable) and any subviews, including any view controllers or views in its subtree.
pub fn setNeedsLayout(&self)
UIResponder only.pub fn layoutIfNeeded(&self)
UIResponder only.pub fn layoutSubviews(&self)
UIResponder only.pub fn preservesSuperviewLayoutMargins(&self) -> bool
UIResponder only.Sourcepub fn setPreservesSuperviewLayoutMargins(
&self,
preserves_superview_layout_margins: bool,
)
Available on crate feature UIResponder only.
pub fn setPreservesSuperviewLayoutMargins( &self, preserves_superview_layout_margins: bool, )
UIResponder only.Setter for preservesSuperviewLayoutMargins.
pub fn insetsLayoutMarginsFromSafeArea(&self) -> bool
UIResponder only.Sourcepub fn setInsetsLayoutMarginsFromSafeArea(
&self,
insets_layout_margins_from_safe_area: bool,
)
Available on crate feature UIResponder only.
pub fn setInsetsLayoutMarginsFromSafeArea( &self, insets_layout_margins_from_safe_area: bool, )
UIResponder only.Setter for insetsLayoutMarginsFromSafeArea.
pub fn layoutMarginsDidChange(&self)
UIResponder only.pub fn safeAreaInsetsDidChange(&self)
UIResponder only.pub fn setNeedsDisplay(&self)
UIResponder only.pub fn clipsToBounds(&self) -> bool
UIResponder only.Sourcepub fn setClipsToBounds(&self, clips_to_bounds: bool)
Available on crate feature UIResponder only.
pub fn setClipsToBounds(&self, clips_to_bounds: bool)
UIResponder only.Setter for clipsToBounds.
pub fn isOpaque(&self) -> bool
UIResponder only.Sourcepub fn setOpaque(&self, opaque: bool)
Available on crate feature UIResponder only.
pub fn setOpaque(&self, opaque: bool)
UIResponder only.Setter for isOpaque.
pub fn clearsContextBeforeDrawing(&self) -> bool
UIResponder only.Sourcepub fn setClearsContextBeforeDrawing(&self, clears_context_before_drawing: bool)
Available on crate feature UIResponder only.
pub fn setClearsContextBeforeDrawing(&self, clears_context_before_drawing: bool)
UIResponder only.Setter for clearsContextBeforeDrawing.
pub fn isHidden(&self) -> bool
UIResponder only.Sourcepub fn setHidden(&self, hidden: bool)
Available on crate feature UIResponder only.
pub fn setHidden(&self, hidden: bool)
UIResponder only.Setter for isHidden.
pub fn contentMode(&self) -> UIViewContentMode
UIResponder only.Sourcepub fn setContentMode(&self, content_mode: UIViewContentMode)
Available on crate feature UIResponder only.
pub fn setContentMode(&self, content_mode: UIViewContentMode)
UIResponder only.Setter for contentMode.
pub fn maskView(&self) -> Option<Retained<UIView>>
UIResponder only.Sourcepub fn setMaskView(&self, mask_view: Option<&UIView>)
Available on crate feature UIResponder only.
pub fn setMaskView(&self, mask_view: Option<&UIView>)
UIResponder only.Setter for maskView.
pub fn tintAdjustmentMode(&self) -> UIViewTintAdjustmentMode
UIResponder only.Sourcepub fn setTintAdjustmentMode(
&self,
tint_adjustment_mode: UIViewTintAdjustmentMode,
)
Available on crate feature UIResponder only.
pub fn setTintAdjustmentMode( &self, tint_adjustment_mode: UIViewTintAdjustmentMode, )
UIResponder only.Setter for tintAdjustmentMode.
pub fn tintColorDidChange(&self)
UIResponder only.pub fn updateConstraintsIfNeeded(&self)
UIResponder only.pub fn updateConstraints(&self)
UIResponder only.pub fn needsUpdateConstraints(&self) -> bool
UIResponder only.pub fn setNeedsUpdateConstraints(&self)
UIResponder only.pub fn translatesAutoresizingMaskIntoConstraints(&self) -> bool
UIResponder only.Sourcepub fn setTranslatesAutoresizingMaskIntoConstraints(
&self,
translates_autoresizing_mask_into_constraints: bool,
)
Available on crate feature UIResponder only.
pub fn setTranslatesAutoresizingMaskIntoConstraints( &self, translates_autoresizing_mask_into_constraints: bool, )
UIResponder only.Setter for translatesAutoresizingMaskIntoConstraints.
pub fn viewForBaselineLayout(&self) -> Retained<UIView>
Override -viewForFirstBaselineLayout or -viewForLastBaselineLayout as appropriate, instead
UIResponder only.pub fn viewForFirstBaselineLayout(&self) -> Retained<UIView>
UIResponder only.pub fn viewForLastBaselineLayout(&self) -> Retained<UIView>
UIResponder only.pub fn invalidateIntrinsicContentSize(&self)
UIResponder only.pub fn hasAmbiguousLayout(&self) -> bool
UIResponder only.pub fn exerciseAmbiguityInLayout(&self)
UIResponder only.pub fn restorationIdentifier(&self) -> Option<Retained<NSString>>
UIResponder only.Sourcepub fn setRestorationIdentifier(
&self,
restoration_identifier: Option<&NSString>,
)
Available on crate feature UIResponder only.
pub fn setRestorationIdentifier( &self, restoration_identifier: Option<&NSString>, )
UIResponder only.Setter for restorationIdentifier.
This is copied when set.
Sourcepub unsafe fn encodeRestorableStateWithCoder(&self, coder: &NSCoder)
Available on crate feature UIResponder only.
pub unsafe fn encodeRestorableStateWithCoder(&self, coder: &NSCoder)
UIResponder only.Safety
coder possibly has further requirements.
Sourcepub unsafe fn decodeRestorableStateWithCoder(&self, coder: &NSCoder)
Available on crate feature UIResponder only.
pub unsafe fn decodeRestorableStateWithCoder(&self, coder: &NSCoder)
UIResponder only.Safety
coder possibly has further requirements.
pub fn snapshotViewAfterScreenUpdates( &self, after_updates: bool, ) -> Option<Retained<UIView>>
UIResponder only.Sourcepub fn appliedContentSizeCategoryLimitsDescription(&self) -> Retained<NSString>
Available on crate feature UIResponder only.
pub fn appliedContentSizeCategoryLimitsDescription(&self) -> Retained<NSString>
UIResponder only.Will return a string with a log of all the superviews of this view, alongside with what content size category each view has and if that view has limits applied. This is for debugging purposes only.
pub fn traitOverrides(&self) -> Retained<ProtocolObject<dyn UITraitOverrides>>
UIResponder and UITraitCollection only.Sourcepub fn updateTraitsIfNeeded(&self)
Available on crate feature UIResponder only.
pub fn updateTraitsIfNeeded(&self)
UIResponder only.Forces an immediate trait update for this view (and its view controller, if applicable) and any subviews, including any view controllers or views in its subtree. Any trait change callbacks are sent synchronously.
Methods from Deref<Target = UIResponder>
pub fn nextResponder(&self) -> Option<Retained<UIResponder>>
pub fn canBecomeFirstResponder(&self) -> bool
pub fn becomeFirstResponder(&self) -> bool
pub fn canResignFirstResponder(&self) -> bool
pub fn resignFirstResponder(&self) -> bool
pub fn isFirstResponder(&self) -> bool
Sourcepub unsafe fn canPerformAction_withSender(
&self,
action: Sel,
sender: Option<&AnyObject>,
) -> bool
pub unsafe fn canPerformAction_withSender( &self, action: Sel, sender: Option<&AnyObject>, ) -> bool
Safety
actionmust be a valid selector.sendershould be of the correct type.
Sourcepub unsafe fn targetForAction_withSender(
&self,
action: Sel,
sender: Option<&AnyObject>,
) -> Option<Retained<AnyObject>>
pub unsafe fn targetForAction_withSender( &self, action: Sel, sender: Option<&AnyObject>, ) -> Option<Retained<AnyObject>>
Safety
actionmust be a valid selector.sendershould be of the correct type.
pub fn undoManager(&self) -> Option<Retained<NSUndoManager>>
pub fn editingInteractionConfiguration( &self, ) -> UIEditingInteractionConfiguration
pub fn inputView(&self) -> Option<Retained<UIView>>
UIView only.pub fn inputAccessoryView(&self) -> Option<Retained<UIView>>
UIView only.pub fn textInputContextIdentifier(&self) -> Option<Retained<NSString>>
pub fn reloadInputViews(&self)
pub fn userActivity(&self) -> Option<Retained<NSUserActivity>>
Sourcepub fn setUserActivity(&self, user_activity: Option<&NSUserActivity>)
pub fn setUserActivity(&self, user_activity: Option<&NSUserActivity>)
Setter for userActivity.
pub fn updateUserActivityState(&self, activity: &NSUserActivity)
pub fn restoreUserActivityState(&self, activity: &NSUserActivity)
Sourcepub unsafe fn captureTextFromCamera(&self, sender: Option<&AnyObject>)
pub unsafe fn captureTextFromCamera(&self, sender: Option<&AnyObject>)
Safety
sender should be of the correct type.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
this is difficult to use correctly, use Ivar::load instead.
Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for ARCoachingOverlayView
impl AsRef<AnyObject> for ARCoachingOverlayView
Sourceimpl AsRef<NSObject> for ARCoachingOverlayView
impl AsRef<NSObject> for ARCoachingOverlayView
Sourceimpl AsRef<UIResponder> for ARCoachingOverlayView
impl AsRef<UIResponder> for ARCoachingOverlayView
Sourcefn as_ref(&self) -> &UIResponder
fn as_ref(&self) -> &UIResponder
Sourceimpl AsRef<UIView> for ARCoachingOverlayView
impl AsRef<UIView> for ARCoachingOverlayView
Sourceimpl Borrow<AnyObject> for ARCoachingOverlayView
impl Borrow<AnyObject> for ARCoachingOverlayView
Sourceimpl Borrow<NSObject> for ARCoachingOverlayView
impl Borrow<NSObject> for ARCoachingOverlayView
Sourceimpl Borrow<UIResponder> for ARCoachingOverlayView
impl Borrow<UIResponder> for ARCoachingOverlayView
Sourcefn borrow(&self) -> &UIResponder
fn borrow(&self) -> &UIResponder
Sourceimpl Borrow<UIView> for ARCoachingOverlayView
impl Borrow<UIView> for ARCoachingOverlayView
Sourceimpl CALayerDelegate for ARCoachingOverlayView
impl CALayerDelegate for ARCoachingOverlayView
fn displayLayer(&self, layer: &CALayer)
fn layerWillDraw(&self, layer: &CALayer)
fn layoutSublayersOfLayer(&self, layer: &CALayer)
fn actionForLayer_forKey( &self, layer: &CALayer, event: &NSString, ) -> Option<Retained<ProtocolObject<dyn CAAction>>>
Sourceimpl ClassType for ARCoachingOverlayView
impl ClassType for ARCoachingOverlayView
Sourceconst NAME: &'static str = "ARCoachingOverlayView"
const NAME: &'static str = "ARCoachingOverlayView"
Sourcetype ThreadKind = <<ARCoachingOverlayView as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<ARCoachingOverlayView as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for ARCoachingOverlayView
impl Debug for ARCoachingOverlayView
Sourceimpl Deref for ARCoachingOverlayView
impl Deref for ARCoachingOverlayView
Sourceimpl Hash for ARCoachingOverlayView
impl Hash for ARCoachingOverlayView
Sourceimpl Message for ARCoachingOverlayView
impl Message for ARCoachingOverlayView
Sourceimpl NSCoding for ARCoachingOverlayView
impl NSCoding for ARCoachingOverlayView
Sourceunsafe fn encodeWithCoder(&self, coder: &NSCoder)
unsafe fn encodeWithCoder(&self, coder: &NSCoder)
NSCoder only.Sourceimpl NSObjectProtocol for ARCoachingOverlayView
impl NSObjectProtocol for ARCoachingOverlayView
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
use isKindOfClass directly, or cast your objects with AnyObject::downcast_ref
Sourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl PartialEq for ARCoachingOverlayView
impl PartialEq for ARCoachingOverlayView
Sourceimpl RefEncode for ARCoachingOverlayView
impl RefEncode for ARCoachingOverlayView
Sourceconst ENCODING_REF: Encoding = <UIView as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <UIView as ::objc2::RefEncode>::ENCODING_REF
Sourceimpl UIAppearance for ARCoachingOverlayView
impl UIAppearance for ARCoachingOverlayView
fn appearance(mtm: MainThreadMarker) -> Retained<Self>
Sourceunsafe fn appearanceWhenContainedInInstancesOfClasses(
container_types: &NSArray<AnyClass>,
mtm: MainThreadMarker,
) -> Retained<Self>
unsafe fn appearanceWhenContainedInInstancesOfClasses( container_types: &NSArray<AnyClass>, mtm: MainThreadMarker, ) -> Retained<Self>
Sourcefn appearanceForTraitCollection(
trait: &UITraitCollection,
mtm: MainThreadMarker,
) -> Retained<Self>
fn appearanceForTraitCollection( trait: &UITraitCollection, mtm: MainThreadMarker, ) -> Retained<Self>
UITraitCollection only.Sourceunsafe fn appearanceForTraitCollection_whenContainedInInstancesOfClasses(
trait: &UITraitCollection,
container_types: &NSArray<AnyClass>,
mtm: MainThreadMarker,
) -> Retained<Self>
unsafe fn appearanceForTraitCollection_whenContainedInInstancesOfClasses( trait: &UITraitCollection, container_types: &NSArray<AnyClass>, mtm: MainThreadMarker, ) -> Retained<Self>
UITraitCollection only.Sourceimpl UIDynamicItem for ARCoachingOverlayView
impl UIDynamicItem for ARCoachingOverlayView
Sourcefn collisionBoundsType(&self) -> UIDynamicItemCollisionBoundsType
fn collisionBoundsType(&self) -> UIDynamicItemCollisionBoundsType
Sourceimpl UIFocusEnvironment for ARCoachingOverlayView
impl UIFocusEnvironment for ARCoachingOverlayView
Sourcefn preferredFocusEnvironments(
&self,
) -> Retained<NSArray<ProtocolObject<dyn UIFocusEnvironment>>>
fn preferredFocusEnvironments( &self, ) -> Retained<NSArray<ProtocolObject<dyn UIFocusEnvironment>>>
Sourcefn parentFocusEnvironment(
&self,
) -> Option<Retained<ProtocolObject<dyn UIFocusEnvironment>>>
fn parentFocusEnvironment( &self, ) -> Option<Retained<ProtocolObject<dyn UIFocusEnvironment>>>
Sourcefn focusItemContainer(
&self,
) -> Option<Retained<ProtocolObject<dyn UIFocusItemContainer>>>
fn focusItemContainer( &self, ) -> Option<Retained<ProtocolObject<dyn UIFocusItemContainer>>>
Sourcefn setNeedsFocusUpdate(&self)
fn setNeedsFocusUpdate(&self)
[[UIFocusSystem focusSystemForEnvironment:self] requestFocusUpdateToEnvironment:self];Sourcefn updateFocusIfNeeded(&self)
fn updateFocusIfNeeded(&self)
[[UIFocusSystem focusSystemForEnvironment:self] updateFocusIfNeeded];.Sourcefn shouldUpdateFocusInContext(&self, context: &UIFocusUpdateContext) -> bool
fn shouldUpdateFocusInContext(&self, context: &UIFocusUpdateContext) -> bool
Sourcefn soundIdentifierForFocusUpdateInContext(
&self,
context: &UIFocusUpdateContext,
) -> Option<Retained<NSString>>
fn soundIdentifierForFocusUpdateInContext( &self, context: &UIFocusUpdateContext, ) -> Option<Retained<NSString>>
Sourceimpl UIFocusItem for ARCoachingOverlayView
impl UIFocusItem for ARCoachingOverlayView
Sourcefn canBecomeFocused(&self) -> bool
fn canBecomeFocused(&self) -> bool
Sourcefn focusGroupPriority(&self) -> isize
fn focusGroupPriority(&self) -> isize
Sourcefn focusItemDeferralMode(&self) -> UIFocusItemDeferralMode
fn focusItemDeferralMode(&self) -> UIFocusItemDeferralMode
UIFocusItemDeferralModeNever, the focus deferral will not be enabled again
after the user engagement timeout has expired if this item is currently focused and programmatic focus updates pointing
to this item will be executed immediatly. If it returns UIFocusItemDeferralModeAlways focus will always be deferred
when this item is supposed to be focused.
Does nothing when focus deferral is not supported on the platform.Sourcefn isTransparentFocusItem(&self) -> bool
fn isTransparentFocusItem(&self) -> bool
Sourceimpl UIFocusItemContainer for ARCoachingOverlayView
impl UIFocusItemContainer for ARCoachingOverlayView
Sourcefn coordinateSpace(&self) -> Retained<ProtocolObject<dyn UICoordinateSpace>>
fn coordinateSpace(&self) -> Retained<ProtocolObject<dyn UICoordinateSpace>>
UIView only.Sourceimpl UIResponderStandardEditActions for ARCoachingOverlayView
impl UIResponderStandardEditActions for ARCoachingOverlayView
Sourceunsafe fn makeTextWritingDirectionLeftToRight(&self, sender: Option<&AnyObject>)
unsafe fn makeTextWritingDirectionLeftToRight(&self, sender: Option<&AnyObject>)
Sourceunsafe fn makeTextWritingDirectionRightToLeft(&self, sender: Option<&AnyObject>)
unsafe fn makeTextWritingDirectionRightToLeft(&self, sender: Option<&AnyObject>)
Sourceimpl UITraitEnvironment for ARCoachingOverlayView
impl UITraitEnvironment for ARCoachingOverlayView
fn traitCollection(&self) -> Retained<UITraitCollection>
Sourcefn traitCollectionDidChange(
&self,
previous_trait_collection: Option<&UITraitCollection>,
)
fn traitCollectionDidChange( &self, previous_trait_collection: Option<&UITraitCollection>, )
Use the trait change registration APIs declared in the UITraitChangeObservable protocol
impl DowncastTarget for ARCoachingOverlayView
impl Eq for ARCoachingOverlayView
impl UIAppearanceContainer for ARCoachingOverlayView
impl UICoordinateSpace for ARCoachingOverlayView