#[repr(transparent)]pub struct ARErrorCode(pub NSInteger);ARError and objc2 only.Expand description
Tuple Fields
0: NSIntegerImplementations
Sourceimpl ARErrorCode
impl ARErrorCode
Sourcepub const UnsupportedConfiguration: Self
pub const UnsupportedConfiguration: Self
Unsupported configuration.
A sensor required to run the session is not available.
Sourcepub const SensorFailed: Self
pub const SensorFailed: Self
A sensor failed to provide the required input.
App does not have permission to use the camera. The user may change this in settings.
App does not have permission to use the microphone. The user may change this in settings.
App does not have permission to use the location data of the device. The user may change this in settings.
Sourcepub const HighResolutionFrameCaptureInProgress: Self
pub const HighResolutionFrameCaptureInProgress: Self
A high-resolution frame is requested while another one is being captured.
Sourcepub const HighResolutionFrameCaptureFailed: Self
pub const HighResolutionFrameCaptureFailed: Self
High-resolution frame capture failed.
Sourcepub const WorldTrackingFailed: Self
pub const WorldTrackingFailed: Self
World tracking has encountered a fatal error.
Sourcepub const GeoTrackingNotAvailableAtLocation: Self
pub const GeoTrackingNotAvailableAtLocation: Self
Geo tracking is not available at this location.
Sourcepub const GeoTrackingFailed: Self
pub const GeoTrackingFailed: Self
Geo tracking has encountered a runtime error.
Sourcepub const InvalidReferenceImage: Self
pub const InvalidReferenceImage: Self
Invalid reference image
Sourcepub const InvalidReferenceObject: Self
pub const InvalidReferenceObject: Self
Invalid reference object.
Sourcepub const InvalidWorldMap: Self
pub const InvalidWorldMap: Self
Invalid world map.
Sourcepub const InvalidConfiguration: Self
pub const InvalidConfiguration: Self
Invalid configuration.
Sourcepub const InvalidCollaborationData: Self
pub const InvalidCollaborationData: Self
Invalid collaboration data.
Sourcepub const InsufficientFeatures: Self
pub const InsufficientFeatures: Self
Insufficient features.
Sourcepub const ObjectMergeFailed: Self
pub const ObjectMergeFailed: Self
Object merge failed.
Sourcepub const FileIOFailed: Self
pub const FileIOFailed: Self
Unable to read or write to file.
Sourcepub const RequestFailed: Self
pub const RequestFailed: Self
Generic request failure.