#[repr(C)]pub struct ARQuickLookPreviewItem { /* private fields */ }ARQuickLookPreviewItem and objc2 only.Expand description
Implementations
Sourceimpl ARQuickLookPreviewItem
impl ARQuickLookPreviewItem
Sourcepub unsafe fn initWithFileAtURL(
this: Allocated<Self>,
url: &NSURL,
) -> Retained<Self>
Available on crate feature objc2-foundation only.
pub unsafe fn initWithFileAtURL( this: Allocated<Self>, url: &NSURL, ) -> Retained<Self>
objc2-foundation only.Creates an object representing the 3D content that will be previewed in AR Quick Look.
This object will be previewed in AR Quick Look using the default behavior:
-
Start in Object mode without camera passthrough
-
Display the Share button for 3D content sharing
-
Allow scaling content in both Object and AR mode
This is a promise to the ARQuickLookPreviewItem class that the URL points to a 3D content file. This class does not deal with the file’s existence or content, and leaves it up to QuickLook to handle and process the URL.
Parameter url: A file URL to 3D content file (e.g. usdz).
Returns: The preview object to display in AR Quick Look.
Sourcepub unsafe fn canonicalWebPageURL(&self) -> Option<Retained<NSURL>>
Available on crate feature objc2-foundation only.
pub unsafe fn canonicalWebPageURL(&self) -> Option<Retained<NSURL>>
objc2-foundation only.An optional canonical web page URL for the 3D content that will be shared.
If this is supplied, the URL to the canonical web page is shared instead of the 3D content file. For example, providing https://developer.apple.com/arkit/gallery/ as the canonical web page URL string will be shared via the Share button. If the web page URL string is malformed or not provided, then AR Quick Look will default to sharing the 3D content.
Sourcepub unsafe fn setCanonicalWebPageURL(
&self,
canonical_web_page_url: Option<&NSURL>,
)
Available on crate feature objc2-foundation only.
pub unsafe fn setCanonicalWebPageURL( &self, canonical_web_page_url: Option<&NSURL>, )
objc2-foundation only.Setter for canonicalWebPageURL.
Sourcepub unsafe fn allowsContentScaling(&self) -> bool
pub unsafe fn allowsContentScaling(&self) -> bool
Whether or not AR Quick Look allows content scaling in AR mode.
Defaults to YES which allows scaling content in AR mode.
Sourcepub unsafe fn setAllowsContentScaling(&self, allows_content_scaling: bool)
pub unsafe fn setAllowsContentScaling(&self, allows_content_scaling: bool)
Setter for allowsContentScaling.
pub unsafe fn new() -> Retained<Self>
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for ARQuickLookPreviewItem
impl AsRef<AnyObject> for ARQuickLookPreviewItem
Sourceimpl AsRef<NSObject> for ARQuickLookPreviewItem
impl AsRef<NSObject> for ARQuickLookPreviewItem
Sourceimpl Borrow<AnyObject> for ARQuickLookPreviewItem
impl Borrow<AnyObject> for ARQuickLookPreviewItem
Sourceimpl Borrow<NSObject> for ARQuickLookPreviewItem
impl Borrow<NSObject> for ARQuickLookPreviewItem
Sourceimpl ClassType for ARQuickLookPreviewItem
impl ClassType for ARQuickLookPreviewItem
Sourceconst NAME: &'static str = "ARQuickLookPreviewItem"
const NAME: &'static str = "ARQuickLookPreviewItem"
Sourcetype ThreadKind = <<ARQuickLookPreviewItem as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<ARQuickLookPreviewItem as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for ARQuickLookPreviewItem
impl Debug for ARQuickLookPreviewItem
Sourceimpl Deref for ARQuickLookPreviewItem
impl Deref for ARQuickLookPreviewItem
Sourceimpl Hash for ARQuickLookPreviewItem
impl Hash for ARQuickLookPreviewItem
Sourceimpl Message for ARQuickLookPreviewItem
impl Message for ARQuickLookPreviewItem
Sourceimpl NSObjectProtocol for ARQuickLookPreviewItem
impl NSObjectProtocol for ARQuickLookPreviewItem
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref