ARAnchorCopying

Trait ARAnchorCopying 

pub unsafe trait ARAnchorCopying: NSCopying {
    // Provided method
    unsafe fn initWithAnchor(
        this: Allocated<Self>,
        anchor: &ARAnchor,
    ) -> Retained<Self>
       where Self: Sized + Message { ... }
}
Available on crate features ARAnchor and objc2 and objc2-foundation only.
An anchor object that can be copied from values of an existing anchor.

See also Apple’s documentation

Provided Methods

unsafe fn initWithAnchor( this: Allocated<Self>, anchor: &ARAnchor, ) -> Retained<Self>
where Self: Sized + Message,

Initializes a new anchor object copying values from an existing anchor.

This initializer will be called any time copy is called on anchor of this class. This method must be implemented for any ARAnchor subclasses that adds properties.

Parameter anchor: The anchor from which to copy values.