ARCoachingOverlayViewDelegate

Trait ARCoachingOverlayViewDelegate 

pub unsafe trait ARCoachingOverlayViewDelegate: NSObjectProtocol {
    // Provided methods
    unsafe fn coachingOverlayViewDidRequestSessionReset(
        &self,
        coaching_overlay_view: &ARCoachingOverlayView,
    )
       where Self: Sized + Message { ... }
    unsafe fn coachingOverlayViewWillActivate(
        &self,
        coaching_overlay_view: &ARCoachingOverlayView,
    )
       where Self: Sized + Message { ... }
    unsafe fn coachingOverlayViewDidDeactivate(
        &self,
        coaching_overlay_view: &ARCoachingOverlayView,
    )
       where Self: Sized + Message { ... }
}
Available on crate features ARCoachingOverlayView and objc2 only.
Provided Methods

unsafe fn coachingOverlayViewDidRequestSessionReset( &self, coaching_overlay_view: &ARCoachingOverlayView, )
where Self: Sized + Message,

Available on crate feature objc2-ui-kit only.

This is called when the user taps the reset button in the relocalization state

By default, when the relocalization reset button is tapped, the overlay will call run on the session using the current configuration, and the ARSessionRunOptionResetTracking and ARSessionRunOptionRemoveExistingAnchors options. The delegate may implement this method to override this behavior. The delegate is then responsible for resetting the session.

Parameter coachingOverlayView: The view currently active

unsafe fn coachingOverlayViewWillActivate( &self, coaching_overlay_view: &ARCoachingOverlayView, )
where Self: Sized + Message,

Available on crate feature objc2-ui-kit only.

This is called when the view activate, either manually or automatically

The Developer may hide their application UI in in this callback, and take other appropriate actions to allow ARCoachingOverlayView to take over the full screen.

Parameter coachingOverlayView: The view that will be activated

unsafe fn coachingOverlayViewDidDeactivate( &self, coaching_overlay_view: &ARCoachingOverlayView, )
where Self: Sized + Message,

Available on crate feature objc2-ui-kit only.

This is called when the view has been deactivated, either manually or automatically

Parameter coachingOverlayView: The view that was deactivated