pub type ARBlendShapeLocation = NSString;Available on crate features
ARFaceAnchor and objc2-foundation only.Expand description
Blend shape locations of a face geometry.
Each location defines an area of the face that can be displaced with a provided coefficient.
Note: Blend shapes are computed based on the captured image. For example, if the detected person has a closed right eye, the eye on the left side of the captured image will appear closed and reported as blend shape activation by ARKit.
See: -[ARFrame capturedImage]
See also Apple’s documentation
Aliased Type
#[repr(C)]pub struct ARBlendShapeLocation { /* private fields */ }